@@ -1,5 +1,7 @@
 from argparse import ArgumentParser
 
+from monutils.db import MAX_SEV_SEL_DELAY
+
 DEF_DB_HOST, DEF_DB_PORT = 'localhost', 27017
 
 
@@ -36,3 +38,5 @@ class MongoArgParser(object):
                             help=f'The CA file to connect to the database. By default, {self.__ca_file}.')
         parser.add_argument('--session_token', type=str, metavar='SESSION', default=self.__session_token,
                             help=f'The session token to connect to the database. By default, {self.__session_token}.')
+        parser.add_argument('--timeout', type=int, metavar='SECONDS', default=MAX_SEV_SEL_DELAY,
+                            help=f'The time to wait for connection confirmation. By default, {MAX_SEV_SEL_DELAY}.')
